@@ -2,7 +2,7 @@
 """
 OnionShare | https://onionshare.org/
 
-Copyright (C) 2017 Micah Lee <micah@micahflee.com>
+Copyright (C) 2018 Micah Lee <micah@micahflee.com>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -178,12 +178,19 @@ def set_gui_mode():
 def debug_mode():
     """
     Turn on debugging mode, which will log flask errors to a debug file.
+
+    This is commented out (it's only needed for debugging, and not needed
+    for OnionShare 1.3.2) as a hotfix to resolve this issue:
+    https://github.com/micahflee/onionshare/issues/837
+    """
+    pass
     """
     temp_dir = tempfile.gettempdir()
     log_handler = logging.FileHandler(
         os.path.join(temp_dir, 'onionshare_server.log'))
     log_handler.setLevel(logging.WARNING)
     app.logger.addHandler(log_handler)
+    """
 
 
 def check_slug_candidate(slug_candidate, slug_compare=None):
